Class: Goethe::Regex

Inherits:
Object
  • Object
show all
Defined in:
lib/goethe/regex.rb

Constant Summary collapse

REGEXEN =
{}
HTML_TAGS =
%w[a abbr address area article aside audio b base bdi bdo blockquote body br button canvas caption cite code col colgroup command data datagrid datalist dd del details dfn div dl font dt em embed eventsource fieldset figcaption figure footer form h1 h2 h3 h4 h5 h6 head header hgroup hr html i iframe img input ins kbd keygen label legend li link mark map menu meta meter nav noscript object ol optgroup option output p param pre progress q ruby rp rt s samp script section select small source span strong style sub summary sup table tbody td textarea tfoot th thead time title tr track u ul var video wbr center]
ADDITIONAL_HTML_TAG =
%w[  ©]

Class Method Summary collapse

Class Method Details

.[](key) ⇒ Object



23
24
25
# File 'lib/goethe/regex.rb', line 23

def self.[](key)
  REGEXEN[key]
end